@@ -51,6 +51,12 @@ class Encoder:
                          df : pd.DataFrame, 
                          ) -> pd.DataFrame: 
 
+        '''
+        encode a dataframe
+        Use case:
+        df = Snaplib().encode_dataframe(df)
+        '''
+
         if not isinstance(df, pd.core.frame.DataFrame):
             raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
 
@@ -104,6 +110,12 @@ class Encoder:
                          df : pd.DataFrame, 
                          ) -> pd.DataFrame: 
 
+        '''
+        encode a dataframe
+        Use case:
+        df = Snaplib().decode_dataframe(df)
+        '''
+
         if not isinstance(df, pd.core.frame.DataFrame):
             raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
 
