@@ -39,9 +39,21 @@ from . import save_load_algorithms
 
 
 
+# from functools import wraps
 
+# def get_docs(func):
+#     @wraps(func)           
+#     def wrapper(*args, **kwargs):
+#         # result = func(*args, **kwargs)
+#         # wrapper.__name__ = func.__name__
+#         wrapper.__doc__ = func.__doc__
+#         return result
+#     return wrapper
 
-
+def get_docs(func):
+    def wrapper(*args, **kwargs):
+        return func(func, *args, **kwargs)
+    return wrapper
 
 
 
@@ -52,58 +64,59 @@ class Snaplib__222:
     ENCODER = encoder.Encoder()
 
 
-
-
     @staticmethod
+    @get_docs
     def nan_info(df : pd.DataFrame) -> pd.DataFrame:
-        '''
-        Get pandas.DataFrame with information about missing data in columns
-        Use case:
-        missing_info_df = Snaplib().nan_info(df)
-        '''
+        # '''
+        # Get pandas.DataFrame with information about missing data in columns
+        # Use case:
+        # missing_info_df = Snaplib().nan_info(df)
+        # '''
         return nans.nan_info(df)
 
 
 
 
     @staticmethod
+    @get_docs
     def nan_plot(df : pd.DataFrame) -> plt.figure:
-        '''
-        Visualise missing data in pandas.DataFrame
-        Use case:
-        Snaplib().nan_plot(df)
-        '''
+        # '''
+        # Visualise missing data in pandas.DataFrame
+        # Use case:
+        # Snaplib().nan_plot(df)
+        # '''
         return nans.nan_plot(df)
 
 
 
 
     @staticmethod
+    @get_docs
     def cleane( df : pd.DataFrame, 
                 target : str = None, 
                 verbose : bool = True
                 ) -> pd.DataFrame: 
-        '''
-        drop_duplicates
-        drop rows with nan in target
-        drop column with 1 unique value
-        Use case:
-        df = Snaplib().cleane(df, target_name, verbose=True)
-        '''
+        # '''
+        # drop_duplicates
+        # drop rows with nan in target
+        # drop column with 1 unique value
+        # Use case:
+        # df = Snaplib().cleane(df, target_name, verbose=True)
+        # '''
         return nans.cleane(df, target, verbose)
 
 
 
-
+    @get_docs
     def encode_dataframe(self, 
                          df : pd.DataFrame, 
                          inplace : bool = False, 
                          ) -> pd.DataFrame: 
-        '''
-        encode a dataframe
-        Use case:
-        df = Snaplib().encode_dataframe(df)
-        '''
+        # '''
+        # encode a dataframe
+        # Use case:
+        # df = Snaplib().encode_dataframe(df)
+        # '''
         if inplace is False:
             df_copied = df.copy()
 
@@ -113,16 +126,16 @@ class Snaplib__222:
 
 
         
-
+    @get_docs
     def decode_dataframe(self, 
                          df : pd.DataFrame, 
                          inplace : bool = False, 
                          ) -> pd.DataFrame: 
-        '''
-        encode a dataframe
-        Use case:
-        df = Snaplib().decode_dataframe(df)
-        '''
+        # '''
+        # encode a dataframe
+        # Use case:
+        # df = Snaplib().decode_dataframe(df)
+        # '''
         if inplace is False:
             df_copied = df.copy()
             return self.ENCODER.decode_dataframe(df_copied)
@@ -138,7 +151,7 @@ class Snaplib__222:
                       k : int, 
                       ) -> dict: 
         '''
-        Return a dictionary list of DataFrames and Series for target
+        Return a dictionary of lists of DataFrames and Series for target
         with next structure:
 
         k_fold_dict = { 
@@ -149,7 +162,7 @@ class Snaplib__222:
                       }
 
         Use case:
-        k_fold_dict_data = Snaplib().k_folds_split( df, target_name, k)
+        k_fold_dict_data = Snaplib().k_folds_split(df, target_name, k)
         '''
         return splitter.k_folds_split(df, target_name, k)
 
@@ -211,7 +224,13 @@ class Snaplib__222:
         Cross Validation method for list of algorithms.
         
         Use case:
-        score = Snaplib().cross_val(algorithms, k_fold_dict, metric, task, cv, verbose=0):
+        score = Snaplib().cross_val(algorithms, 
+                                    k_fold_dict, 
+                                    metric, 
+                                    task, 
+                                    cv, 
+                                    verbose=0, 
+                                    early_stopping_rounds=0)
         
         algorithms is a list of algorithms like algs = [
                                                         [LGBMClassifier, dict(params)],
@@ -231,7 +250,7 @@ class Snaplib__222:
         Get k_fold_dict:
         k_fold_dict = Snaplib().k_folds_split(df, target_name_str, K_FOLD)
               
-        metric is a metric like f1_score or mean_absolute_error.
+        metric is a metric like f1_score or mean_absolute_error : Callable.
         task='clsf' or 'regr', classification or regression.
         cv is num K_FOLD integer 
         verbose = 0 mute, 1 verbose.
@@ -263,7 +282,7 @@ class Snaplib__222:
         Use case:
         df = Snaplib().recover_data(df, verbose=True, discrete_columns="auto")
         device must be "cpu" or "gpu". Sometime small datasets work faster with cpu.
-        if set verbose = if True algorithm runs cross validation tests and print results of tests for decision making.
+        if set verbose=True algorithm runs cross validation tests and print results of tests for decision making.
         discrete_columns = ['col_name_1', 'col_name_2', 'col_name_3', 'etc']
 
         TESTS on https://www.kaggle.com/code/artyomkolas/nan-prediction-in-progress/notebook
@@ -379,7 +398,7 @@ class Snaplib__222:
         df = pandas.core.frame.DataFrame.
         target = name of target of str type.
 
-        metric is a metric like f1_score or mean_absolute_error.
+        metric is a metric like f1_score or mean_absolute_error : Callable.
         cv is num K_FOLD integer 
         verbose = 0 mute, 1 verbose.
         early_stopping_rounds default 0 or positive int.
@@ -430,7 +449,7 @@ class Snaplib__222:
         df = pandas.core.frame.DataFrame.
         target = name of target of str type.
                 
-        metric is a metric like f1_score or mean_absolute_error.
+        metric is a metric like f1_score or mean_absolute_error : Callable.
         cv is num K_FOLD integer 
         verbose = 0 mute, 1 verbose.
         early_stopping_rounds default 0 or positive int.
@@ -2314,5 +2333,3 @@ class Snaplib:
 
 
 
-
-
